# QuanEstimation

| **Documentation**         |
|:------------------------- |
| [![Stable](https://img.shields.io/badge/docs-stable-blue.svg)](https://quanestimation.github.io/QuanEstimation/) | 

QuanEstimation is a Python-Julia based open-source toolkit for quantum parameter estimation, which consist in the calculation of the quantum metrological tools and quantum resources, and the optimizations with respect to the probe states, the controls or the measurements, as well as comprehensive optimizations in quantum metrology. Futhermore, QuanEstimation can generate not only optimal quantum parameter estimation schemes, but also adaptive measurement schemes.

## Documentation
The documentation of QuanEstimation can be found [here](https://quanestimation.github.io/QuanEstimation/).

## Installation
Run the command in the terminal to install QuanEstimation:  

~~~
pip install quanestimation
~~~

## Citation
If you use QuanEstimation in your research, please cite the following paper:

[1] M. Zhang, H.-M. Yu, H. Yuan, X. Wang, R. Demkowicz-Dobrzański, and J. Liu, 
QuanEstimation: An open-source toolkit for quantum parameter estimation, 
[arXiv:2205.15588](https://doi.org/10.48550/arXiv.2205.15588).
